#!/usr/bin/env python
# -*- coding: utf-8 -*-

import time
import datetime
"""
日期时间工具类
"""


class DateUtils(object):

    @staticmethod
    def get_first_last_by_month(year=None, month=None, format_str='%Y-%m-%d %H:%M:%S'):
        """
            根据年份，月份获取当月第一天和当月最后一天
        """
        year, month, day = DateUtils._check_null(year, month)
        this_mouth_first = datetime.datetime(year, month, 1, 0, 0, 0)
        future_mouth_first = DateUtils.get_future_mouth_first(year, month)
        this_mouth_last = future_mouth_first - datetime.timedelta(days=1)
        return this_mouth_first.strftime(format_str), this_mouth_last.strftime(format_str)

    @staticmethod
    def get_first_last_by_day(year=None, month=None, day=None, format_str='%Y-%m-%d %H:%M:%S'):
        """
        根据年份和月份和日，获取指定日期的第一秒钟和最后一秒钟
        """
        year, month, day = DateUtils._check_null(year, month, day)
        this_day_first = datetime.datetime(year, month, day, 0, 0, 0)
        this_day_last = datetime.datetime(year, month, day, 23, 59, 59)
        return this_day_first.strftime(format_str), this_day_last.strftime(format_str)

    @staticmethod
    def get_future_mouth_first(year, month):
        """
        获取下个月第一天
        """
        if month == 12:
            month = 0
            year = year + 1
        future_mouth_first = datetime.datetime(year, month + 1, 1, 0, 0, 0)
        return future_mouth_first

    @staticmethod
    def _check_null(year=None, month=None, day=None):
        """
        监测年月日，默认为今天
        """
        now_time = datetime.datetime.now()
        if year is None:
            year = now_time.year
        if month is None:
            month = now_time.month
        if day is None:
            day = now_time.day
        return year, month, day

    @staticmethod
    def get_timestamp():
        """
        获取当前时间戳
        """
        t = time.time()
        return int(round(t * 1000))

    @staticmethod
    def now(t: datetime = None, format_str='%Y-%m-%d %H:%M:%S'):
        """
        获取格式化时间撮当前时间
        """
        if t is None:
            t = datetime.datetime.now()
        return t.strftime(format_str)


if __name__ == '__main__':
    pass



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from pywkmisc import get_config

class MimeTypeUtils(object):

    # http://www.iana.org/assignments/media-types/media-types.xhtml#text
    def __init__(self):
        self.__mime_types = [
            {'mimetype': 'application/octet-stream', 'ext': '.'},
            {'mimetype': 'video/x-sgi-movie', 'ext': '.movie'},
            {'mimetype': 'video/x-ms-wvx', 'ext': '.wvx'},
            {'mimetype': 'video/x-ms-wmx', 'ext': '.wmx'},
            {'mimetype': 'video/x-ms-wmv', 'ext': '.wmv'},
            {'mimetype': 'video/x-ms-wm', 'ext': '.wm'},
            {'mimetype': 'video/x-ms-asf', 'ext': '.asf'},
            {'mimetype': 'video/x-mpg', 'ext': '.mpa'},
            {'mimetype': 'video/x-mpeg', 'ext': '.m2v'},
            {'mimetype': 'video/x-ivf', 'ext': '.IVF'},
            {'mimetype': 'video/vnd.rn-realvideo', 'ext': '.rv'},
            {'mimetype': 'video/mpg', 'ext': '.mpeg'},
            {'mimetype': 'video/mpeg4', 'ext': '.mp4'},
            {'mimetype': 'video/mpeg', 'ext': '.mp2v'},
            {'mimetype': 'video/avi', 'ext': '.avi'},
            {'mimetype': 'text/x-vcard', 'ext': '.vcf'},
            {'mimetype': 'text/x-ms-odc', 'ext': '.odc'},
            {'mimetype': 'text/xml', 'ext': '.xml'},
            {'mimetype': 'text/x-component', 'ext': '.htc'},
            {'mimetype': 'text/webviewhtml', 'ext': '.htt'},
            {'mimetype': 'text/vnd.wap.wml', 'ext': '.wml'},
            {'mimetype': 'text/vnd.rn-realtext3d', 'ext': '.r3t'},
            {'mimetype': 'text/vnd.rn-realtext', 'ext': '.rt'},
            {'mimetype': 'text/scriptlet', 'ext': '.wsc'},
            {'mimetype': 'text/plain', 'ext': '.txt'},
            {'mimetype': 'text/iuls', 'ext': '.uls'},
            {'mimetype': 'text/html', 'ext': '.htm'},
            {'mimetype': 'text/h323', 'ext': '0.323'},
            {'mimetype': 'text/css', 'ext': '.css'},
            {'mimetype': 'text/asp', 'ext': '.asp'},
            {'mimetype': 'text/asa', 'ext': '.asa'},
            {'mimetype': 'Model/vnd.dwf', 'ext': '.dwf'},
            {'mimetype': 'message/rfc822', 'ext': '.mht'},
            {'mimetype': 'java/*', 'ext': '.java'},
            {'mimetype': 'image/x-icon', 'ext': '.ico'},
            {'mimetype': 'image/vnd.wap.wbmp', 'ext': '.wbmp'},
            {'mimetype': 'image/vnd.rn-realpix', 'ext': '.rp'},
            {'mimetype': 'image/tiff', 'ext': '.tif'},
            {'mimetype': 'image/png', 'ext': '.png'},
            {'mimetype': 'image/pnetvue', 'ext': '.net'},
            {'mimetype': 'image/jpeg', 'ext': '.jpg'},
            {'mimetype': 'image/gif', 'ext': '.gif'},
            {'mimetype': 'image/fax', 'ext': '.fax'},
            {'mimetype': 'drawing/x-top', 'ext': '.top'},
            {'mimetype': 'drawing/x-slk', 'ext': '.slk'},
            {'mimetype': 'drawing/907', 'ext': '0.907'},
            {'mimetype': 'audio/x-pn-realaudio-plugin', 'ext': '.rpm'},
            {'mimetype': 'audio/x-pn-realaudio', 'ext': '.ram'},
            {'mimetype': 'audio/x-musicnet-stream', 'ext': '.mns'},
            {'mimetype': 'audio/x-musicnet-download', 'ext': '.mnd'},
            {'mimetype': 'audio/x-ms-wma', 'ext': '.wma'},
            {'mimetype': 'audio/x-ms-wax', 'ext': '.wax'},
            {'mimetype': 'audio/x-mei-aac', 'ext': '.acp'},
            {'mimetype': 'audio/x-liquid-secure', 'ext': '.lavs'},
            {'mimetype': 'audio/x-liquid-file', 'ext': '.la1'},
            {'mimetype': 'audio/x-la-lms', 'ext': '.lmsff'},
            {'mimetype': 'audio/wav', 'ext': '.wav'},
            {'mimetype': 'audio/vnd.rn-realaudio', 'ext': '.ra'},
            {'mimetype': 'audio/scpls', 'ext': '.xpl'},
            {'mimetype': 'audio/rn-mpeg', 'ext': '.mpga'},
            {'mimetype': 'audio/mpegurl', 'ext': '.m3u'},
            {'mimetype': 'audio/mp3', 'ext': '.mp3'},
            {'mimetype': 'audio/mp2', 'ext': '.mp2'},
            {'mimetype': 'audio/mp1', 'ext': '.mp1'},
            {'mimetype': 'audio/mid', 'ext': '.mid'},
            {'mimetype': 'audio/basic', 'ext': '.au'},
            {'mimetype': 'audio/aiff', 'ext': '.aif'},
            {'mimetype': 'application/x-xwd', 'ext': '.xwd'},
            {'mimetype': 'application/x-xlw', 'ext': '.xlw'},
            {'mimetype': 'application/x-xls', 'ext': '.xls'},
            {'mimetype': 'application/x-x509-ca-cert', 'ext': '.der'},
            {'mimetype': 'application/x-x509-ca-cert', 'ext': '.cer'},
            {'mimetype': 'application/x-x509-ca-cert', 'ext': '.crt'},
            {'mimetype': 'application/x-x_t', 'ext': '.x_t'},
            {'mimetype': 'application/x-x_b', 'ext': '.x_b'},
            {'mimetype': 'application/x-ws', 'ext': '.ws'},
            {'mimetype': 'application/x-wrk', 'ext': '.wrk'},
            {'mimetype': 'application/x-wri', 'ext': '.wri'},
            {'mimetype': 'application/x-wr1', 'ext': '.wr1'},
            {'mimetype': 'application/x-wq1', 'ext': '.wq1'},
            {'mimetype': 'application/x-wpg', 'ext': '.wpg'},
            {'mimetype': 'application/x-wpd', 'ext': '.wpd'},
            {'mimetype': 'application/x-wp6', 'ext': '.wp6'},
            {'mimetype': 'application/x-wmf', 'ext': '.wmf'},
            {'mimetype': 'application/x-wks', 'ext': '.wks'},
            {'mimetype': 'application/x-wkq', 'ext': '.wkq'},
            {'mimetype': 'application/x-wk4', 'ext': '.wk4'},
            {'mimetype': 'application/x-wk3', 'ext': '.wk3'},
            {'mimetype': 'application/x-wb3', 'ext': '.wb3'},
            {'mimetype': 'application/x-wb2', 'ext': '.wb2'},
            {'mimetype': 'application/x-wb1', 'ext': '.wb1'},
            {'mimetype': 'application/x-vst', 'ext': '.vst'},
            {'mimetype': 'application/x-vsd', 'ext': '.vsd'},
            {'mimetype': 'application/x-vpeg005', 'ext': '.vpg'},
            {'mimetype': 'application/x-vda', 'ext': '.vda'},
            {'mimetype': 'application/x-troff-man', 'ext': '.man'},
            {'mimetype': 'application/x-tif', 'ext': '.tif'},
            {'mimetype': 'application/x-tga', 'ext': '.tga'},
            {'mimetype': 'application/x-tg4', 'ext': '.tg4'},
            {'mimetype': 'application/x-tdf', 'ext': '.tdf'},
            {'mimetype': 'application/x-sty', 'ext': '.sty'},
            {'mimetype': 'application/x-stuffit', 'ext': '.sit'},
            {'mimetype': 'application/x-smk', 'ext': '.smk'},
            {'mimetype': 'application/x-sld', 'ext': '.sld'},
            {'mimetype': 'application/x-slb', 'ext': '.slb'},
            {'mimetype': 'application/x-shockwave-flash', 'ext': '.swf'},
            {'mimetype': 'application/x-sdw', 'ext': '.sdw'},
            {'mimetype': 'application/x-sat', 'ext': '.sat'},
            {'mimetype': 'application/x-sam', 'ext': '.sam'},
            {'mimetype': 'application/x-rtf', 'ext': '.rtf'},
            {'mimetype': 'application/x-rle', 'ext': '.rle'},
            {'mimetype': 'application/x-rlc', 'ext': '.rlc'},
            {'mimetype': 'application/x-rgb', 'ext': '.rgb'},
            {'mimetype': 'application/x-red', 'ext': '.red'},
            {'mimetype': 'application/x-ras', 'ext': '.ras'},
            {'mimetype': 'application/x-ptn', 'ext': '.ptn'},
            {'mimetype': 'application/x-ps', 'ext': '.ps'},
            {'mimetype': 'application/x-prt', 'ext': '.prt'},
            {'mimetype': 'application/x-prn', 'ext': '.prn'},
            {'mimetype': 'application/x-pr', 'ext': '.pr'},
            {'mimetype': 'application/x-ppt', 'ext': '.ppt'},
            {'mimetype': 'application/x-ppm', 'ext': '.ppm'},
            {'mimetype': 'application/x-png', 'ext': '.png'},
            {'mimetype': 'application/x-plt', 'ext': '.plt'},
            {'mimetype': 'application/x-pkcs7-certreqresp', 'ext': '.p7r'},
            {'mimetype': 'application/x-pkcs7-certificates', 'ext': '.p7b'},
            {'mimetype': 'application/x-pkcs12', 'ext': '.pfx'},
            {'mimetype': 'application/x-pic', 'ext': '.pic'},
            {'mimetype': 'application/x-pgl', 'ext': '.pgl'},
            {'mimetype': 'application/x-perl', 'ext': '.pl'},
            {'mimetype': 'application/x-pcx', 'ext': '.pcx'},
            {'mimetype': 'application/x-pcl', 'ext': '.pcl'},
            {'mimetype': 'application/x-pci', 'ext': '.pci'},
            {'mimetype': 'application/x-pc5', 'ext': '.pc5'},
            {'mimetype': 'application/json', 'ext': '.json'},
            {'mimetype': 'application/x-out', 'ext': '.out'},
            {'mimetype': 'application/x-nrf', 'ext': '.nrf'},
            {'mimetype': 'application/x-netcdf', 'ext': '.cdf'},
            {'mimetype': 'application/x-ms-wmz', 'ext': '.wmz'},
            {'mimetype': 'application/x-ms-wmd', 'ext': '.wmd'},
            {'mimetype': 'application/x-msdownload', 'ext': '.exe'},
            {'mimetype': 'application/x-mmxp', 'ext': '.mxp'},
            {'mimetype': 'application/x-mil', 'ext': '.mil'},
            {'mimetype': 'application/x-mi', 'ext': '.mi'},
            {'mimetype': 'application/x-mdb', 'ext': '.mdb'},
            {'mimetype': 'application/x-mac', 'ext': '.mac'},
            {'mimetype': 'application/x-ltr', 'ext': '.ltr'},
            {'mimetype': 'application/x-lbm', 'ext': '.lbm'},
            {'mimetype': 'application/x-latex', 'ext': '.latex'},
            {'mimetype': 'application/x-laplayer-reg', 'ext': '.lar'},
            {'mimetype': 'application/x-jpg', 'ext': '.jpg'},
            {'mimetype': 'application/x-jpe', 'ext': '.jpe'},
            {'mimetype': 'application/x-javascript', 'ext': '.js'},
            {'mimetype': 'application/x-iphone', 'ext': '.iii'},
            {'mimetype': 'application/x-internet-signup', 'ext': '.ins'},
            {'mimetype': 'application/x-img', 'ext': '.img'},
            {'mimetype': 'application/x-igs', 'ext': '.igs'},
            {'mimetype': 'application/x-iff', 'ext': '.iff'},
            {'mimetype': 'application/x-icq', 'ext': '.uin'},
            {'mimetype': 'application/x-ico', 'ext': '.ico'},
            {'mimetype': 'application/x-icb', 'ext': '.icb'},
            {'mimetype': 'application/x-hrf', 'ext': '.hrf'},
            {'mimetype': 'application/x-hpl', 'ext': '.hpl'},
            {'mimetype': 'application/x-hpgl', 'ext': '.hpg'},
            {'mimetype': 'application/x-hmr', 'ext': '.hmr'},
            {'mimetype': 'application/x-hgl', 'ext': '.hgl'},
            {'mimetype': 'application/x-gp4', 'ext': '.gp4'},
            {'mimetype': 'application/x-gl2', 'ext': '.gl2'},
            {'mimetype': 'application/x-gbr', 'ext': '.gbr'},
            {'mimetype': 'application/x-g4', 'ext': '.g4'},
            {'mimetype': 'application/x-frm', 'ext': '.frm'},
            {'mimetype': 'application/x-epi', 'ext': '.epi'},
            {'mimetype': 'application/x-emf', 'ext': '.emf'},
            {'mimetype': 'application/x-ebx', 'ext': '.etd'},
            {'mimetype': 'application/x-dxf', 'ext': '.dxf'},
            {'mimetype': 'application/x-dxb', 'ext': '.dxb'},
            {'mimetype': 'application/x-dwg', 'ext': '.dwg'},
            {'mimetype': 'application/x-dwf', 'ext': '.dwf'},
            {'mimetype': 'application/x-drw', 'ext': '.drw'},
            {'mimetype': 'application/x-dib', 'ext': '.dib'},
            {'mimetype': 'application/x-dgn', 'ext': '.dgn'},
            {'mimetype': 'application/x-dcx', 'ext': '.dcx'},
            {'mimetype': 'application/x-dbx', 'ext': '.dbx'},
            {'mimetype': 'application/x-dbm', 'ext': '.dbm'},
            {'mimetype': 'application/x-dbf', 'ext': '.dbf'},
            {'mimetype': 'application/x-cut', 'ext': '.cut'},
            {'mimetype': 'application/x-csi', 'ext': '.csi'},
            {'mimetype': 'application/x-cot', 'ext': '.cot'},
            {'mimetype': 'application/x-cmx', 'ext': '.cmx'},
            {'mimetype': 'application/x-cmp', 'ext': '.cmp'},
            {'mimetype': 'application/x-cit', 'ext': '.cit'},
            {'mimetype': 'application/x-cgm', 'ext': '.cgm'},
            {'mimetype': 'application/x-cel', 'ext': '.cel'},
            {'mimetype': 'application/x-cdr', 'ext': '.cdr'},
            {'mimetype': 'application/x-cals', 'ext': '.cal'},
            {'mimetype': 'application/x-c90', 'ext': '.c90'},
            {'mimetype': 'application/x-c4t', 'ext': '.c4t'},
            {'mimetype': 'application/x-bot', 'ext': '.bot'},
            {'mimetype': 'application/x-bmp', 'ext': '.bmp'},
            {'mimetype': 'application/x-bittorrent', 'ext': '.torrent'},
            {'mimetype': 'application/x-anv', 'ext': '.anv'},
            {'mimetype': 'application/x-a11', 'ext': '.a11'},
            {'mimetype': 'application/x-906', 'ext': '0.906'},
            {'mimetype': 'application/x-301', 'ext': '0.301'},
            {'mimetype': 'application/x-001', 'ext': '0.001'},
            {'mimetype': 'application/x-', 'ext': '.'},
            {'mimetype': 'application/vnd.visio', 'ext': '.vsx'},
            {'mimetype': 'application/vnd.symbian.install', 'ext': '.sis'},
            {'mimetype': 'application/vnd.rn-rsml', 'ext': '.rsml'},
            {'mimetype': 'application/vnd.rn-rn_music_package', 'ext': '.rmp'},
            {'mimetype': 'application/vnd.rn-recording', 'ext': '.rec'},
            {'mimetype': 'application/vnd.rn-realsystem-rmx', 'ext': '.rmx'},
            {'mimetype': 'application/vnd.rn-realsystem-rmj', 'ext': '.rmj'},
            {'mimetype': 'application/vnd.rn-realsystem-rjt', 'ext': '.rjt'},
            {'mimetype': 'application/vnd.rn-realsystem-rjs', 'ext': '.rjs'},
            {'mimetype': 'application/vnd.rn-realplayer', 'ext': '.rnx'},
            {'mimetype': 'application/vnd.rn-realmedia-vbr', 'ext': '.rmvb'},
            {'mimetype': 'application/vnd.rn-realmedia-secure', 'ext': '.rms'},
            {'mimetype': 'application/vnd.rn-realmedia', 'ext': '.rm'},
            {'mimetype': 'application/vnd.ms-wpl', 'ext': '.wpl'},
            {'mimetype': 'application/vnd.ms-project', 'ext': '.mpt'},
            {'mimetype': 'application/vnd.ms-powerpoint', 'ext': '.ppt'},
            {'mimetype': 'application/vnd.ms-pki.stl', 'ext': '.stl'},
            {'mimetype': 'application/vnd.ms-pki.seccat', 'ext': '.cat'},
            {'mimetype': 'application/vnd.ms-pki.pko', 'ext': '.pko'},
            {'mimetype': 'application/vnd.ms-pki.certstore', 'ext': '.sst'},
            {'mimetype': 'application/vnd.ms-excel', 'ext': '.xls'},
            {'mimetype': 'application/vnd.iphone', 'ext': '.ipa'},
            {'mimetype': 'application/vnd.fdf', 'ext': '.fdf'},
            {'mimetype': 'application/vnd.android.package-archive', 'ext': '.apk'},
            {'mimetype': 'application/vnd.adobe.xfdf', 'ext': '.xfdf'},
            {'mimetype': 'application/vnd.adobe.xfd', 'ext': '.xfd'},
            {'mimetype': 'application/vnd.adobe.xdp', 'ext': '.xdp'},
            {'mimetype': 'application/vnd.adobe.workflow', 'ext': '.awf'},
            {'mimetype': 'application/vnd.adobe.rmf', 'ext': '.rmf'},
            {'mimetype': 'application/vnd.adobe.pdx', 'ext': '.pdx'},
            {'mimetype': 'application/vnd.adobe.edn', 'ext': '.edn'},
            {'mimetype': 'application/streamingmedia', 'ext': '.ssm'},
            {'mimetype': 'application/smil', 'ext': '.smi'},
            {'mimetype': 'application/sdp', 'ext': '.sdp'},
            {'mimetype': 'application/rat-file', 'ext': '.rat'},
            {'mimetype': 'application/postscript', 'ext': '.ps'},
            {'mimetype': 'application/pkix-crl', 'ext': '.crl'},
            {'mimetype': 'application/pkcs7-signature', 'ext': '.p7s'},
            {'mimetype': 'application/pkcs7-mime', 'ext': '.p7c'},
            {'mimetype': 'application/pkcs10', 'ext': '.p10'},
            {'mimetype': 'application/pics-rules', 'ext': '.prf'},
            {'mimetype': 'application/pdf', 'ext': '.pdf'},
            {'mimetype': 'application/msword', 'ext': '.doc'},
            {'mimetype': 'application/msaccess', 'ext': '.mdb'},
            {'mimetype': 'application/mac-binhex40', 'ext': '.hqx'},
            {'mimetype': 'application/hta', 'ext': '.hta'},
            {'mimetype': 'application/futuresplash', 'ext': '.spl'},
            {'mimetype': 'application/fractals', 'ext': '.fif'},
            {'mimetype': 'video/x-flv', 'ext': '.flv'},     #Flash
            {'mimetype': 'video/mp4', 'ext': '.mp4'},       #MPEG-4
            {'mimetype': 'video/MP2T', 'ext': '.ts'},        #iPhone Segment
            {'mimetype': 'video/3gpp', 'ext': '.3gp'},
            {'mimetype': 'video/x-ms-wmv', 'ext': '.wmv'},
            {'mimetype': 'video/x-msvideo', 'ext': '.avi'},
            {'mimetype': 'video/quicktime', 'ext': '.mov'},
            {'mimetype': 'application/x-mpegURL', 'ext': '.m3u8'}
        ]
        us_mime = get_config('mimetype')
        if us_mime:
            self.__mime_types = self.__mime_types + us_mime

    def get_content_type_ext(self, conttype):
        for mime in self.__mime_types:
            if conttype and conttype == mime['mimetype']:
                return mime['ext']

    @staticmethod
    def get_content_type(headers):
        if 'Content-Type' in headers and headers['Content-Type']:
            conttype = headers['Content-Type']
            if conttype.find(';') > 0:
                return conttype.split(';')[0]
            return conttype


if __name__ == '__main__':
    pass



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import json
import requests
import logging.config
from contextlib import closing
from pywkmisc import DateUtils
from .mimetype_utils import MimeTypeUtils
'''
Created on 2020年7月22日

@author: wangkai

定义一些系统变量
'''

logger = logging.getLogger('httpclient')


class HttpClientUtils(object):
    SYSTEM_VERSION = "spider-sdk-python-VersionNo"

    @staticmethod
    def get(url,
            params={},
            headers={'cache-control': "no-cache"},
            method='GET',
            payload=None,
            verify=True,
            proxies=True):
        """
        获取网络对象
        :param url:						网址
        :param params:				参数
        :param headers:				头部信息
        :param method:				请求类型 GET POST PUT
        :param payload:				请求data数据
        :param verify:				证书代理
        :return:							网络请求信息
        """
        logger.info(url)
        if proxies is True:
            return requests.request(method,
                                    url,
                                    data=payload,
                                    headers=headers,
                                    params=params,
                                    timeout=100,
                                    verify=verify)
        else:
            return requests.request(method,
                                    url,
                                    data=payload,
                                    headers=headers,
                                    params=params,
                                    timeout=100,
                                    verify=verify)

    @staticmethod
    def getjson(url,
                params={},
                headers={'cache-control': "no-cache"},
                method='GET',
                payload=None,
                verify=True,
                proxies=None):
        """
        网络对象转为文本
        :param url: 网址
        :param params: 参数
        :param headers: 头部信息
        :param method: 请求类型 GET POST PUT
        :param payload: 请求data数据
        :param verify: 证书代理
        :param proxies: 是否使用代理服务器
        :return: JSON数据
        """
        response = HttpClientUtils.get(url, params, headers, method, payload, verify, proxies)
        return json.loads(response.text)

    @staticmethod
    def _get_ext(qheader,default_ext = None):
        if default_ext:
            return default_ext
        ext = MimeTypeUtils().get_content_type_ext(
            MimeTypeUtils().get_content_type(qheader.headers))
        return ext

    @staticmethod
    def save_file(url,
                  savepath,
                  params={},
                  headers={'cache-control': "no-cache"},
                  method='GET',
                  save_file_name=None,
                  ext=None,
                  payload=None,
                  verify=True):
        qheader = HttpClientUtils.request_head(url)

        # todo 获取不到文件的大小的问题
        content_length = 0
        if 'Content-Length' in qheader:
            content_length = qheader.headers['Content-Length'] | 0
        _file_size = HttpClientUtils.size_format(content_length)
        ext = HttpClientUtils._get_ext(qheader, ext)
        if save_file_name is None:
            save_file_name = str(DateUtils.get_timestamp())
        save_file_name = "{}{}{}".format(savepath, save_file_name, ext)
        i = 0
        with closing(requests.request(method,
                                      url,
                                      data=payload,
                                      headers=headers,
                                      params=params,
                                      timeout=100,
                                      verify=verify,
                                      stream=True)) as res:
            old_bfb = ''

            if content_length == 0:
                logger.debug('获取不到文件大小')
            else:
                logger.debug('{}(size:{})->{}'.format(url, _file_size, save_file_name))
            with open(save_file_name, "wb") as f:
                for chunk in res.iter_content(chunk_size=1024):
                    if chunk:
                        i += len(chunk)
                        f.write(chunk)
                        if content_length >0:
                            bfb = '{:.0%}'.format(i/int(content_length))
                            if bfb != old_bfb:
                                old_bfb = bfb
                                print('\r{bfb}({chunk}/{total}),'.format(bfb=bfb, chunk=HttpClientUtils.size_format(i), total=_file_size), end="")
                        else:
                            print('\r{chunk},'.format(chunk=HttpClientUtils.size_format(i)), end="")
            print('')
        return save_file_name

    @staticmethod
    def size_format(size, is_disk=False, precision=2):
        formats = ['KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB']
        unit = 1000.0 if is_disk else 1024.0
        if isinstance(size, str):
            size = int(size)
        if not(isinstance(size, float) or isinstance(size, int)):
            raise TypeError('a float number or an integer number is required!')
        if size < 0:
            raise ValueError('number must be non-negative')
        for i in formats:
            size /= unit
            if size < unit:
                return f'{round(size, precision)}{i}'
        return f'{round(size, precision)}{i}'

    @staticmethod
    def request_head(url, headers={'cache-control': "no-cache"}):
        response = requests.head(url, headers=headers)
        if 'Location' in response.headers:
            if url != response.headers['Location']:
                return HttpClientUtils.request_head(response.headers['Location'])
        return response


if __name__ == '__main__':
    pass



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from pywkmisc.config import Config
from pywkmisc.date_utils import DateUtils
from pywkmisc.file_utils import FileUtils
from pywkmisc.image_utils import ImageUtils
from pywkmisc.string_utils import StringUtils

_config = None

if _config is None:
    import os
    if os.path.exists('../conf/'):
        _config = Config('../conf/')
    if os.path.exists('conf/'):
        _config = Config('conf/')

@property
def config():
    global _config
    return _config


def get_config(key):
    global _config
    if _config is None:
        return _config
    return _config.get_basic(key)


def get_configs(key):
    global _config
    if _config is None:
        return _config
    return _config.gets_basic(key)


from pywkmisc.http_client_utils import HttpClientUtils
from pywkmisc.mimetype_utils import MimeTypeUtils
from pywkmisc.multipartform_data import MultipartFormData




from pywkmisc import FileUtils


class ImageUtils(FileUtils):

    def __init__(self, file_path):
        """
        :param file_path:   磁盘图片文件路径
        """
        super(ImageUtils, self).__init__(file_path)
        try:
            from PIL import Image
            self._img: Image = Image.open(self._file_path)
        except ImportError:
            print('ImageHash 未安装 ，pip install ImageHash')

    @property
    def width(self):
        return self._img.width

    @property
    def height(self):
        return self._img.height

    @property
    def size(self):
        return self._img.size

    def dhash(self):
        try:
            import imagehash
            return str(imagehash.dhash(self._img))
        except ImportError:
            print('ImageHash 未安装 ，pip install ImageHash')

    def getexif(self):
        return self._img.getexif()

    def thumbnail(self, size, resample=None, reducing_gap=None):
        """同比缩放"""
        return self._img.thumbnail(size, resample, reducing_gap)

    def resize(self, size, resample=None, box=None, reducing_gap=None):
        """缩放图片"""
        return self._img.resize(size, resample, box, reducing_gap)

    @staticmethod
    def getimagedhash(filepath):
        """
        获取图片的dhash值，计算图片相识度
            dhash = ImageUtils.getimagedhash('./../qiao.jpg')\n
            print(dhash)\n
            =========\n
            4b6b694766791946
        :param filepath:        文件路径
        :return:                图片dhash数据
        """
        return ImageUtils(filepath).dhash()

    def del_file(self):
        try:
            if self._img is not None:
                self._img.close()
        except Exception as e:
            pass
        super(ImageUtils, self).del_file()

    def __del__(self):
        try:
            if self._img is not None:
                self._img.close()
        except Exception as e:
            pass


if __name__ == '__main__':
    pass



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import json
import jsonpath


class Config(object):

    def __init__(self, cfp=None):
        self._cfp = cfp     # config_folder_path
        self._config: dict = {}
        self._check_path()
        self._get_config()

    def _check_path(self):
        if self._cfp is None:
            self._cfp = os.path.abspath('conf/')
        else:
            self._cfp = os.path.abspath(self._cfp)
        self._cfp = self._cfp.replace('\\', os.sep)
        self._cfp = self._cfp.replace('/', os.sep)
        if not self._cfp[len(self._cfp)-1] == os.sep:
            self._cfp += os.sep
        if not os.path.exists(self._cfp):
            raise RuntimeError('{}路径不存在'.format(self._cfp))

    def _get_config(self):
        for file in os.listdir(self._cfp):
            with open('{path}{file}'.format(path=self._cfp, file=file), 'r', encoding='utf8') as f:
                self._config[file.split('.', 2)[0]] = json.load(f)

    def get_basic(self, key):
        return self.get('base',key)

    def gets_basic(self, key):
        return self._gets('base', key)

    def get(self, c_type, key):
        return self._get(c_type, '$.{key}'.format(key=key))

    def gets(self, c_type, key):
        return self._gets(c_type, '$.{key}'.format(key=key))

    def _gets(self, c_type, key):
        return jsonpath.jsonpath(self._config[c_type], key)

    def _get(self, c_type, key):
        _v = self._gets(c_type, key)
        if _v:
            return _v[0]



#!/usr/bin/env python
# -*- coding: utf-8 -*-

class MultipartFormData(object):
    """multipart/form-data格式转化"""

    @staticmethod
    def format(data, boundary="----WebKitFormBoundary7MA4YWxkTrZu0gW", headers={}):
        """
        form data
        :param: data:  {"req":{"cno":"18990876","flag":"Y"},"ts":1,"sig":1,"v": 2.0}
        :param: boundary: "----WebKitFormBoundary7MA4YWxkTrZu0gW"
        :param: headers: 包含boundary的头信息；如果boundary与headers同时存在以headers为准
        :return: str
        :rtype: str
        """
        # 从headers中提取boundary信息
        if "content-type" in headers:
            fd_val = str(headers["content-type"])
            if "boundary" in fd_val:
                fd_val = fd_val.split(";")[1].strip()
                boundary = fd_val.split("=")[1].strip()
            else:
                raise Exception("multipart/form-data头信息错误，请检查content-type key是否包含boundary")
        # form-data格式定式
        jion_str = '--{}\r\nContent-Disposition: form-data; name="{}"\r\n\r\n{}\r\n\r\n'
        end_str = "--{}--".format(boundary)
        args_str = ""

        if not isinstance(data, dict):
            raise Exception("multipart/form-data参数错误，data参数应为dict类型")
        for key, value in data.items():
            args_str = args_str + jion_str.format(boundary, key, value)

        args_str = args_str + end_str.format(boundary)
        # 我屮艸芔茻
        #args_str = args_str.replace("\'", "\"")
        return args_str


#!/usr/bin/env python
# -*- coding: utf-8 -*-

import hashlib
import uuid as _uuid
import time
import random


class StringUtils(object):

    @staticmethod
    def str2md5(string):
        """
        字符串转MD5
        1、参数必须是utf8
        2、python3 所有字符都是unicode形式，已经不存在unicode关键字
        3、python3 str 实质上就是unicode
        """
        if isinstance(string, str):
            # 如果是unicode先转utf-8
            string = string.encode("utf-8")
        m = hashlib.md5()
        m.update(string)
        return m.hexdigest()

    @staticmethod
    def uuid(ns, string, avoid_conflict=True):
        if avoid_conflict:
            data = '{ns}{node}{time}{str}{rand}'.format(
                ns=ns[:12],
                node=_uuid.getnode(),
                time=time.time() * 1000000,
                str=string,
                rand=random.randint(23, 6436343)
            )
        else:
            data = '{ns}{node}{str}'.format(ns=ns[:12], node=_uuid.getnode(), str=string)
        return StringUtils.str2md5(data.encode())

    @staticmethod
    def sha1(string):
        sha1 = hashlib.sha1()
        sha1.update(string)
        return sha1.hexdigest()

    @staticmethod
    def sha512(string):
        sha512 = hashlib.sha512()
        sha512.update(string)
        return sha512.hexdigest()

    @staticmethod
    def empty(string):
        """
        StringUtils.empty(None)      = true
        StringUtils.empty("")        = true
        StringUtils.empty(" ")       = false
        StringUtils.empty("bob")     = false
        StringUtils.empty("  bob  ") = false
        :return:
        """
        return string is None or len(string) == 0

    @staticmethod
    def blank(string):
        """
        StringUtils.blank(None)      = true
        StringUtils.blank("")        = true
        StringUtils.blank(" ")       = true
        StringUtils.blank("bob")     = false
        StringUtils.blank("  bob  ") = false
        :return:
        """
        if string is None or len(string) == 0:
            return True
        return string.isspace()


if __name__ == '__main__':
    pass



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os


class FileUtils(object):

    def __init__(self, file_path):
        """
        :param file_path:   磁盘文件路径
        """
        self._file_path = file_path
        self._path, self._file_name = os.path.split(self._file_path)
        self._path = os.path.abspath(self._path)
        self._shot_name, self._extension = os.path.splitext(self._file_name)

    def read(self):
        s: dict = {
            'filepath': self.filepath,
            'path': self.path,
            'filename': self.filename,
            'shotname': self.shotname,
            'extension': self.extension,
        }
        return str(s).replace('\'', '"')

    @property
    def filepath(self):
        """获取磁盘文件完整路径，虚拟路径转为完整路径"""
        return '{}{}{}'.format(self._path, os.sep, self.filename)

    @property
    def filesize(self):
        return os.path.getsize(self.filepath)

    @property
    def path(self):
        """获取磁盘文件保存绝对地址"""
        return self._path

    @property
    def filename(self):
        """获取磁盘文件包含扩展名的文件名"""
        return self._file_name

    @property
    def shotname(self):
        """获取磁盘文件不包含扩展名的文件名"""
        return self._shot_name

    @property
    def extension(self):
        """获取磁盘文件的扩展名,包含."""
        return self._extension

    def exists(self):
        """
        判断存放图片的文件夹是否存在
        """
        if self._path is None:
            return False
        return os.path.exists(self._path)

    def makedirs(self):
        """
        判断存放文件夹是否存在,若文件夹不存在就创建
        """
        if self._path is None:
            return
        if not self.exists():
            os.makedirs(self._path)

    def del_file(self):
        """
        删除磁盘文件
        """
        if self._file_path is None:
            return
        if os.path.exists(self._file_path):
            os.remove(self._file_path)


if __name__ == '__main__':
    pass
